==> jooq-meta-3.19.29-sources.jar: org/jooq/meta/jaxb/ObjectFactory.java <==

package org.jooq.meta.jaxb;

import jakarta.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.jooq.meta.jaxb package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.jooq.meta.jaxb
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link Configuration }
     * 
     */
    public Configuration createConfiguration() {
        return new Configuration();
    }

    /**
     * Create an instance of {@link Jdbc }
     * 
     */
    public Jdbc createJdbc() {
        return new Jdbc();
    }

    /**
     * Create an instance of {@link Generator }
     * 
     */
    public Generator createGenerator() {
        return new Generator();
    }

    /**
     * Create an instance of {@link Property }
     * 
     */
    public Property createProperty() {
        return new Property();
    }

    /**
     * Create an instance of {@link Strategy }
     * 
     */
    public Strategy createStrategy() {
        return new Strategy();
    }

    /**
     * Create an instance of {@link Matchers }
     * 
     */
    public Matchers createMatchers() {
        return new Matchers();
    }

    /**
     * Create an instance of {@link MatchersCatalogType }
     * 
     */
    public MatchersCatalogType createMatchersCatalogType() {
        return new MatchersCatalogType();
    }

    /**
     * Create an instance of {@link MatchersSchemaType }
     * 
     */
    public MatchersSchemaType createMatchersSchemaType() {
        return new MatchersSchemaType();
    }

    /**
     * Create an instance of {@link MatchersTableType }
     * 
     */
    public MatchersTableType createMatchersTableType() {
        return new MatchersTableType();
    }

    /**
     * Create an instance of {@link MatchersIndexType }
     * 
     */
    public MatchersIndexType createMatchersIndexType() {
        return new MatchersIndexType();
    }

    /**
     * Create an instance of {@link MatchersPrimaryKeyType }
     * 
     */
    public MatchersPrimaryKeyType createMatchersPrimaryKeyType() {
        return new MatchersPrimaryKeyType();
    }

    /**
     * Create an instance of {@link MatchersUniqueKeyType }
     * 
     */
    public MatchersUniqueKeyType createMatchersUniqueKeyType() {
        return new MatchersUniqueKeyType();
    }

    /**
     * Create an instance of {@link MatchersForeignKeyType }
     * 
     */
    public MatchersForeignKeyType createMatchersForeignKeyType() {
        return new MatchersForeignKeyType();
    }

    /**
     * Create an instance of {@link MatchersFieldType }
     * 
     */
    public MatchersFieldType createMatchersFieldType() {
        return new MatchersFieldType();
    }

    /**
     * Create an instance of {@link MatchersRoutineType }
     * 
     */
    public MatchersRoutineType createMatchersRoutineType() {
        return new MatchersRoutineType();
    }

    /**
     * Create an instance of {@link MatchersSequenceType }
     * 
     */
    public MatchersSequenceType createMatchersSequenceType() {
        return new MatchersSequenceType();
    }

    /**
     * Create an instance of {@link MatchersEnumType }
     * 
     */
    public MatchersEnumType createMatchersEnumType() {
        return new MatchersEnumType();
    }

    /**
     * Create an instance of {@link MatchersEmbeddableType }
     * 
     */
    public MatchersEmbeddableType createMatchersEmbeddableType() {
        return new MatchersEmbeddableType();
    }

    /**
     * Create an instance of {@link MatchersUDTType }
     * 
     */
    public MatchersUDTType createMatchersUDTType() {
        return new MatchersUDTType();
    }

    /**
     * Create an instance of {@link MatchersAttributeType }
     * 
     */
    public MatchersAttributeType createMatchersAttributeType() {
        return new MatchersAttributeType();
    }

    /**
     * Create an instance of {@link MatcherRule }
     * 
     */
    public MatcherRule createMatcherRule() {
        return new MatcherRule();
    }

    /**
     * Create an instance of {@link Database }
     * 
     */
    public Database createDatabase() {
        return new Database();
    }

    /**
     * Create an instance of {@link CommentType }
     * 
     */
    public CommentType createCommentType() {
        return new CommentType();
    }

    /**
     * Create an instance of {@link SyntheticObjectsType }
     * 
     */
    public SyntheticObjectsType createSyntheticObjectsType() {
        return new SyntheticObjectsType();
    }

    /**
     * Create an instance of {@link SyntheticReadonlyColumnType }
     * 
     */
    public SyntheticReadonlyColumnType createSyntheticReadonlyColumnType() {
        return new SyntheticReadonlyColumnType();
    }

    /**
     * Create an instance of {@link SyntheticReadonlyRowidType }
     * 
     */
    public SyntheticReadonlyRowidType createSyntheticReadonlyRowidType() {
        return new SyntheticReadonlyRowidType();
    }

    /**
     * Create an instance of {@link SyntheticColumnType }
     * 
     */
    public SyntheticColumnType createSyntheticColumnType() {
        return new SyntheticColumnType();
    }

    /**
     * Create an instance of {@link SyntheticIdentityType }
     * 
     */
    public SyntheticIdentityType createSyntheticIdentityType() {
        return new SyntheticIdentityType();
    }

    /**
     * Create an instance of {@link SyntheticEnumType }
     * 
     */
    public SyntheticEnumType createSyntheticEnumType() {
        return new SyntheticEnumType();
    }

    /**
     * Create an instance of {@link SyntheticPrimaryKeyType }
     * 
     */
    public SyntheticPrimaryKeyType createSyntheticPrimaryKeyType() {
        return new SyntheticPrimaryKeyType();
    }

    /**
     * Create an instance of {@link SyntheticUniqueKeyType }
     * 
     */
    public SyntheticUniqueKeyType createSyntheticUniqueKeyType() {
        return new SyntheticUniqueKeyType();
    }

    /**
     * Create an instance of {@link SyntheticForeignKeyType }
     * 
     */
    public SyntheticForeignKeyType createSyntheticForeignKeyType() {
        return new SyntheticForeignKeyType();
    }

    /**
     * Create an instance of {@link SyntheticViewType }
     * 
     */
    public SyntheticViewType createSyntheticViewType() {
        return new SyntheticViewType();
    }

    /**
     * Create an instance of {@link SyntheticDaoType }
     * 
     */
    public SyntheticDaoType createSyntheticDaoType() {
        return new SyntheticDaoType();
    }

    /**
     * Create an instance of {@link SyntheticDaoMethodType }
     * 
     */
    public SyntheticDaoMethodType createSyntheticDaoMethodType() {
        return new SyntheticDaoMethodType();
    }

    /**
     * Create an instance of {@link CatalogMappingType }
     * 
     */
    public CatalogMappingType createCatalogMappingType() {
        return new CatalogMappingType();
    }

    /**
     * Create an instance of {@link SchemaMappingType }
     * 
     */
    public SchemaMappingType createSchemaMappingType() {
        return new SchemaMappingType();
    }

    /**
     * Create an instance of {@link CustomType }
     * 
     */
    public CustomType createCustomType() {
        return new CustomType();
    }

    /**
     * Create an instance of {@link EnumType }
     * 
     */
    public EnumType createEnumType() {
        return new EnumType();
    }

    /**
     * Create an instance of {@link EmbeddableDefinitionType }
     * 
     */
    public EmbeddableDefinitionType createEmbeddableDefinitionType() {
        return new EmbeddableDefinitionType();
    }

    /**
     * Create an instance of {@link EmbeddableField }
     * 
     */
    public EmbeddableField createEmbeddableField() {
        return new EmbeddableField();
    }

    /**
     * Create an instance of {@link ForcedType }
     * 
     */
    public ForcedType createForcedType() {
        return new ForcedType();
    }

    /**
     * Create an instance of {@link LambdaConverter }
     * 
     */
    public LambdaConverter createLambdaConverter() {
        return new LambdaConverter();
    }

    /**
     * Create an instance of {@link Generate }
     * 
     */
    public Generate createGenerate() {
        return new Generate();
    }

    /**
     * Create an instance of {@link Target }
     * 
     */
    public Target createTarget() {
        return new Target();
    }

}

==> jooq-meta-3.20.3-sources.jar: org/jooq/meta/jaxb/ObjectFactory.java <==

package org.jooq.meta.jaxb;

import jakarta.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.jooq.meta.jaxb package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.jooq.meta.jaxb
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link Configuration }
     * 
     */
    public Configuration createConfiguration() {
        return new Configuration();
    }

    /**
     * Create an instance of {@link Jdbc }
     * 
     */
    public Jdbc createJdbc() {
        return new Jdbc();
    }

    /**
     * Create an instance of {@link Generator }
     * 
     */
    public Generator createGenerator() {
        return new Generator();
    }

    /**
     * Create an instance of {@link Property }
     * 
     */
    public Property createProperty() {
        return new Property();
    }

    /**
     * Create an instance of {@link Strategy }
     * 
     */
    public Strategy createStrategy() {
        return new Strategy();
    }

    /**
     * Create an instance of {@link Matchers }
     * 
     */
    public Matchers createMatchers() {
        return new Matchers();
    }

    /**
     * Create an instance of {@link MatchersCatalogType }
     * 
     */
    public MatchersCatalogType createMatchersCatalogType() {
        return new MatchersCatalogType();
    }

    /**
     * Create an instance of {@link MatchersSchemaType }
     * 
     */
    public MatchersSchemaType createMatchersSchemaType() {
        return new MatchersSchemaType();
    }

    /**
     * Create an instance of {@link MatchersTableType }
     * 
     */
    public MatchersTableType createMatchersTableType() {
        return new MatchersTableType();
    }

    /**
     * Create an instance of {@link MatchersIndexType }
     * 
     */
    public MatchersIndexType createMatchersIndexType() {
        return new MatchersIndexType();
    }

    /**
     * Create an instance of {@link MatchersPrimaryKeyType }
     * 
     */
    public MatchersPrimaryKeyType createMatchersPrimaryKeyType() {
        return new MatchersPrimaryKeyType();
    }

    /**
     * Create an instance of {@link MatchersUniqueKeyType }
     * 
     */
    public MatchersUniqueKeyType createMatchersUniqueKeyType() {
        return new MatchersUniqueKeyType();
    }

    /**
     * Create an instance of {@link MatchersForeignKeyType }
     * 
     */
    public MatchersForeignKeyType createMatchersForeignKeyType() {
        return new MatchersForeignKeyType();
    }

    /**
     * Create an instance of {@link MatchersFieldType }
     * 
     */
    public MatchersFieldType createMatchersFieldType() {
        return new MatchersFieldType();
    }

    /**
     * Create an instance of {@link MatchersRoutineType }
     * 
     */
    public MatchersRoutineType createMatchersRoutineType() {
        return new MatchersRoutineType();
    }

    /**
     * Create an instance of {@link MatchersSequenceType }
     * 
     */
    public MatchersSequenceType createMatchersSequenceType() {
        return new MatchersSequenceType();
    }

    /**
     * Create an instance of {@link MatchersEnumType }
     * 
     */
    public MatchersEnumType createMatchersEnumType() {
        return new MatchersEnumType();
    }

    /**
     * Create an instance of {@link MatchersEmbeddableType }
     * 
     */
    public MatchersEmbeddableType createMatchersEmbeddableType() {
        return new MatchersEmbeddableType();
    }

    /**
     * Create an instance of {@link MatchersUDTType }
     * 
     */
    public MatchersUDTType createMatchersUDTType() {
        return new MatchersUDTType();
    }

    /**
     * Create an instance of {@link MatchersAttributeType }
     * 
     */
    public MatchersAttributeType createMatchersAttributeType() {
        return new MatchersAttributeType();
    }

    /**
     * Create an instance of {@link MatcherRule }
     * 
     */
    public MatcherRule createMatcherRule() {
        return new MatcherRule();
    }

    /**
     * Create an instance of {@link Database }
     * 
     */
    public Database createDatabase() {
        return new Database();
    }

    /**
     * Create an instance of {@link CommentType }
     * 
     */
    public CommentType createCommentType() {
        return new CommentType();
    }

    /**
     * Create an instance of {@link SyntheticObjectsType }
     * 
     */
    public SyntheticObjectsType createSyntheticObjectsType() {
        return new SyntheticObjectsType();
    }

    /**
     * Create an instance of {@link SyntheticReadonlyColumnType }
     * 
     */
    public SyntheticReadonlyColumnType createSyntheticReadonlyColumnType() {
        return new SyntheticReadonlyColumnType();
    }

    /**
     * Create an instance of {@link SyntheticReadonlyRowidType }
     * 
     */
    public SyntheticReadonlyRowidType createSyntheticReadonlyRowidType() {
        return new SyntheticReadonlyRowidType();
    }

    /**
     * Create an instance of {@link SyntheticColumnType }
     * 
     */
    public SyntheticColumnType createSyntheticColumnType() {
        return new SyntheticColumnType();
    }

    /**
     * Create an instance of {@link SyntheticIdentityType }
     * 
     */
    public SyntheticIdentityType createSyntheticIdentityType() {
        return new SyntheticIdentityType();
    }

    /**
     * Create an instance of {@link SyntheticDefaultType }
     * 
     */
    public SyntheticDefaultType createSyntheticDefaultType() {
        return new SyntheticDefaultType();
    }

    /**
     * Create an instance of {@link SyntheticEnumType }
     * 
     */
    public SyntheticEnumType createSyntheticEnumType() {
        return new SyntheticEnumType();
    }

    /**
     * Create an instance of {@link SyntheticPrimaryKeyType }
     * 
     */
    public SyntheticPrimaryKeyType createSyntheticPrimaryKeyType() {
        return new SyntheticPrimaryKeyType();
    }

    /**
     * Create an instance of {@link SyntheticUniqueKeyType }
     * 
     */
    public SyntheticUniqueKeyType createSyntheticUniqueKeyType() {
        return new SyntheticUniqueKeyType();
    }

    /**
     * Create an instance of {@link SyntheticForeignKeyType }
     * 
     */
    public SyntheticForeignKeyType createSyntheticForeignKeyType() {
        return new SyntheticForeignKeyType();
    }

    /**
     * Create an instance of {@link SyntheticSynonymType }
     * 
     */
    public SyntheticSynonymType createSyntheticSynonymType() {
        return new SyntheticSynonymType();
    }

    /**
     * Create an instance of {@link SyntheticViewType }
     * 
     */
    public SyntheticViewType createSyntheticViewType() {
        return new SyntheticViewType();
    }

    /**
     * Create an instance of {@link SyntheticDaoType }
     * 
     */
    public SyntheticDaoType createSyntheticDaoType() {
        return new SyntheticDaoType();
    }

    /**
     * Create an instance of {@link SyntheticDaoMethodType }
     * 
     */
    public SyntheticDaoMethodType createSyntheticDaoMethodType() {
        return new SyntheticDaoMethodType();
    }

    /**
     * Create an instance of {@link CatalogMappingType }
     * 
     */
    public CatalogMappingType createCatalogMappingType() {
        return new CatalogMappingType();
    }

    /**
     * Create an instance of {@link SchemaMappingType }
     * 
     */
    public SchemaMappingType createSchemaMappingType() {
        return new SchemaMappingType();
    }

    /**
     * Create an instance of {@link CustomType }
     * 
     */
    public CustomType createCustomType() {
        return new CustomType();
    }

    /**
     * Create an instance of {@link EnumType }
     * 
     */
    public EnumType createEnumType() {
        return new EnumType();
    }

    /**
     * Create an instance of {@link EmbeddableDefinitionType }
     * 
     */
    public EmbeddableDefinitionType createEmbeddableDefinitionType() {
        return new EmbeddableDefinitionType();
    }

    /**
     * Create an instance of {@link EmbeddableField }
     * 
     */
    public EmbeddableField createEmbeddableField() {
        return new EmbeddableField();
    }

    /**
     * Create an instance of {@link ForcedType }
     * 
     */
    public ForcedType createForcedType() {
        return new ForcedType();
    }

    /**
     * Create an instance of {@link LambdaConverter }
     * 
     */
    public LambdaConverter createLambdaConverter() {
        return new LambdaConverter();
    }

    /**
     * Create an instance of {@link Generate }
     * 
     */
    public Generate createGenerate() {
        return new Generate();
    }

    /**
     * Create an instance of {@link Target }
     * 
     */
    public Target createTarget() {
        return new Target();
    }

}
